Trait option_operations::add::OptionWrappingAdd [−][src]
pub trait OptionWrappingAdd<Rhs = Self, InnerRhs = Rhs> {
type Output;
fn opt_wrapping_add(self, rhs: Rhs) -> Option<Self::Output>;
}Expand description
Trait for values and Options wrapping addition.
Implementing this type leads to the following auto-implementations:
OptionWrappingAdd<Option<InnerRhs>>forT.OptionWrappingAdd<Rhs>forOption<T>.OptionWrappingAdd<Option<InnerRhs>>forOption<T>.- … and some variants with references.
Note that since the std library doesn’t define any WrappingAdd
trait, users must provide the base implementation for the inner type.
Associated Types
Required methods
fn opt_wrapping_add(self, rhs: Rhs) -> Option<Self::Output>
fn opt_wrapping_add(self, rhs: Rhs) -> Option<Self::Output>
Computes the addition, wrapping around at the numeric bounds instead of overflowing.
Returns None if at least one argument is None.