Trait option_operations::div::OptionWrappingDiv [−][src]
pub trait OptionWrappingDiv<Rhs = Self, InnerRhs = Rhs> {
type Output;
fn opt_wrapping_div(self, rhs: Rhs) -> Option<Self::Output>;
}Expand description
Trait for values and Options wrapping division.
Implementing this type leads to the following auto-implementations:
OptionWrappingDiv<Option<InnerRhs>>forT.OptionWrappingDiv<Rhs>forOption<T>.OptionWrappingDiv<Option<InnerRhs>>forOption<T>.- … and some variants with references.
Note that since the std library doesn’t define any WrappingDiv
trait, users must provide the base implementation for the inner type.
Associated Types
Required methods
fn opt_wrapping_div(self, rhs: Rhs) -> Option<Self::Output>
fn opt_wrapping_div(self, rhs: Rhs) -> Option<Self::Output>
Computes the division, wrapping around at the numeric bounds instead of overflowing.
Returns None if at least one argument is None.
Panics
Most implementations will panic if rhs is 0.